==> 2.10.zip: piwigo/language/zh_TW/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+


$lang['Upgrade'] = "升級";
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = "此頁面將把您的 Piwigo 舊版本的數據庫升級為新版本。
升級助手將會認為您正在運行 <strong>版本 %s</strong> (或者相同的版本).";
$lang['Upgrade from version %s to %s'] = "從 %s 版升級到 %s";
$lang['Statistics'] = "統計";
$lang['total upgrade time'] = "總共升級時間";
$lang['total SQL time'] = "總共 SQL 時間";
$lang['SQL queries'] = "SQL 查詢";
$lang['Upgrade informations'] = "升級信息";
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = "如果您遇到任何問題，請在[管理員>工具>維護]執行維護檢測";
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = "為了預防萬一，以下插件已被停用。在您重新啟用它們之前，必須先檢查這些插件的更新:";
$lang['Only administrator can run upgrade: please sign in below.'] = "只有管理員能運行升級操作：請先登錄。";
$lang['You do not have access rights to run upgrade'] = "您沒有執行升級程序的權限";
$lang['All sub-albums of private albums become private'] = '相冊裡的所有子相冊都成為私有';
$lang['User permissions and group permissions have been erased'] = "用戶和組的權限已被清除";
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = "在前一個配置操作中，只有縮略圖的前綴和網站管理員的郵件地址被保存了。";
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = '在 <i>%s</i>, 之前 <b>?></b>, 插入:';
$lang['As a precaution, following themes have been deactivated. You must check for themes upgrade before reactiving them:'] = '為小心起見，以下主題已停用。假如要重新啟用它們，你必須先檢查有沒有可更新的主題:';

?>

==> 14.5.0.zip: piwigo/language/zh_TW/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+


$lang['Upgrade'] = "升級";
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = "此頁面將把您的 Piwigo 舊版本的數據庫升級為新版本。
升級助手將會認為您正在運行 <strong>版本 %s</strong> (或者相同的版本).";
$lang['Upgrade from version %s to %s'] = "從 %s 版升級到 %s";
$lang['Statistics'] = "統計";
$lang['total upgrade time'] = "總共升級時間";
$lang['total SQL time'] = "總共 SQL 時間";
$lang['SQL queries'] = "SQL 查詢";
$lang['Upgrade informations'] = '升級資訊';
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = "如果您遇到任何問題，請在[管理員>工具>維護]執行維護檢測";
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = "為了預防萬一，以下插件已被停用。在您重新啟用它們之前，必須先檢查這些插件的更新:";
$lang['Only administrator can run upgrade: please sign in below.'] = "只有管理員能運行升級操作：請先登錄。";
$lang['You do not have access rights to run upgrade'] = "您沒有執行升級程序的權限";
$lang['All sub-albums of private albums become private'] = '相冊裡的所有子相冊都成為私有';
$lang['User permissions and group permissions have been erased'] = "用戶和組的權限已被清除";
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = "在前一個配置操作中，只有縮略圖的前綴和網站管理員的郵件地址被保存了。";
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = '在 <i>%s</i> 中、<b>?></b> 之前，插入：';
$lang['As a precaution, following themes have been deactivated. You must check for themes upgrade before reactiving them:'] = '為小心起見，以下主題已停用。假如要重新啟用它們，你必須先檢查有沒有可更新的主題:';

$lang['Discover what\'s new in Piwigo %s'] = '來看看 Piwigo %s 加入了哪些新玩意兒';
